/* trees.C--Example from Chapter 7 of User's Guide */

/* This program creates a table and a bar chart plot from a
   set of tree diameter readings, and calculates hollow avilability for
   selected hollow users in Western Australia. It uses pointers and is more
   efficeint and seems to work OK*/




#include <conio.h>
#include <ctype.h>
#include <stdio.h>
#include <stdlib.h>
#include <graphics.h>
#include <math.h>
#include <float.h>

/* Prototypes */


void  table_view(void);
void  graph_view(void);
void  class(float *tot, float *pc1);
void  btp(float *btp, float *btpu, float *btpl);
void  galah(float *g, float *gu, float *gl);
void  cor(float *c, float *cu, float *cl);
void  plp(float *pl2, float *plu, float *pll);
void  hollows(void);
void  read_temps(void);
void  assumption(void);
void  output(void);
void  restart(void);
void  space(void);
void  growhi(void);
void  growlo(void);
void  harvest(void);
void  ingrowth(void);


/* Global defines */


#define TRUE      1
#define READINGS  500

/* Global data structures */


float trees[READINGS][5];
int count = 0; float max = 0;
int time = 0;

int  main(void)
{
      _control87(MCW_EM,MCW_EM);
      while (TRUE)
   {
        clrscr();
	printf("\tJARRAH HOLLOW PREDICTION MODEL");
	printf("\n\t\tprepared by Bill McComb");

      
      printf("\nHollow Estimation Menu\n\n");
      printf("\tA - Model Assumptions\n");
      printf("\tR - Read a disk file with data\n");
      printf("\tH - View the Hollow estimates for each species\n");
      printf("\tZ - List and view spatial considerations\n");
      printf("\tT - Table of the tree diameter\n");
      printf("\t    class distribution\n");
      printf("\tC - View a bar chart of the diameter class distribution\n");
      printf("\tG - Grow a very high or high quality stand\n");
      printf("\tL - Grow a medium or low quality stand\n");
      printf("\tV - Harvest trees from the stand\n");
      printf("\tI - Add ingrowth trees to the stand\n");
      printf("\tF - Save results to a disk file for later printing\n");
      printf("\tN - Restart the program (enter new data)\n");
      printf("\tX - Exit the program\n");
      printf("\nPress one of the above keys: ");

      switch (toupper(getche()))
      {
	 case 'A': assumption(); break;
	 case 'R': read_temps(); break;
	 case 'H': hollows(); break;
	 case 'Z': space(); break;
	 case 'T': table_view(); break;
	 case 'C': graph_view(); break;
	 case 'G': growhi(); break;
	 case 'L': growlo(); break;
	 case 'V': harvest(); break;
         case 'I': ingrowth(); break;
	 case 'F': output(); break;
	 case 'N': restart(); break;
	 case 'X': exit(0);

      }
   }
}

/* Function definitions */
void  read_temps(void)
{

   FILE *infile;
   char file_name[512] = "test";
   int reading = 0;
   count = 0;

   printf("\n\n\n");
   printf("\nNOTE: your ASCII file should contain the tree dbhob (cm), space,");
   printf("\ntrees per hectare, space, and a code for living (1) or dead (0).");
   printf("\nFor instance:");
   printf("\n 10.1 0.21 1");
   printf("\nThe last line should contain a -1 in the first 2 columns\n\n");
   printf("\nRead from which file? ");
   while (kbhit());  /* "eat" any char already in keyboard buffer */
   gets(file_name);

   if ((infile = fopen(file_name,"r")) == NULL)
   {
      perror("\n\aOpen failed! ");
         getch();                               /* Wait for a key press */
	clrscr();
      return;
   }
	for (reading = 1; reading < READINGS; reading++)
      {
	fscanf(infile, "%f %f %f\n", &trees[reading][1], &trees[reading][2], &trees[reading][3]);
	if (trees[reading][1] == -1) break;
	count += 1;
	 }

	fclose(infile);

	printf("\nA total of %d trees were read\n\n", count);
	printf("Press any key to continue");

        getch();                               /* Wait for a key press */
	clrscr();
}

void class(float *tot, float *pc1)

{
      int reading = 0;
      max = 0;
      for (reading = 1; reading < count + 1; reading++)
       {
       max += trees[reading][2];
	   if (trees[reading][1] < 10.00)
		tot[1] += trees[reading][2];
	else if (trees[reading][1] < 20.00)
		tot[2] += trees[reading][2];
	else if (trees[reading][1] < 30.00)
		tot[3] += trees[reading][2];
	else if (trees[reading][1] < 40.00)
		tot[4] += trees[reading][2];
	else if (trees[reading][1] < 50.00)
		tot[5] += trees[reading][2];
	else if (trees[reading][1] < 60.00)
		tot[6] += trees[reading][2];
	else if (trees[reading][1] < 70.00)
		tot[7] += trees[reading][2];
	else if (trees[reading][1] < 80.00)
		tot[8] += trees[reading][2];
	else if (trees[reading][1] < 90.00)
		tot[9] += trees[reading][2];
	else if (trees[reading][1] < 100.00)
		tot[10] += trees[reading][2];
	else if (trees[reading][1] < 1000.00)
		tot[11] += trees[reading][2];
	else tot[12] +=trees[reading][2];
	}


      for (reading = 1; reading < 12; reading++)
	  pc1[reading] = (((tot[reading] + 0.1) / max) * 100);

}

void  btp(float *btp, float *btpu, float *btpl)

   /*brush-tailed possum*/
{
	int reading; float pbtp[READINGS]; float pbtpl[READINGS]; float pbtpu[READINGS];
	float n[READINGS]; float s[READINGS]; float c[READINGS];
        float s1[READINGS]; float s2[READINGS];
	float b1 = 0; float bu1 = 0; float bl1 = 0;
	for (reading = 1; reading < count + 1; reading++)

		{

		n[reading] = (4.14 - (trees[reading][1]) * 0.0557);
                s1[reading] = pow (trees[reading][1], 2) * 0.000034;
		s2[reading] = 0.00438 * trees[reading][1];
		s[reading] = 0.15472 + s1[reading] - s2[reading];
		c[reading] = (sqrt (s[reading])) * 1.96;

		pbtp[reading] = (1 / (1 + exp (n[reading])));
		pbtpl[reading] = (1 / (1 + exp (n[reading] - c[reading])));
		pbtpu[reading] = (1 / (1 + exp (n[reading] + c[reading])));

                if (trees[reading][1] < 31.00) pbtp[reading] = 0;
		if (trees[reading][1] < 31.00) pbtpu[reading] = 0;
		if (trees[reading][1] < 31.00) pbtpl[reading] = 0;

		b1 += pbtp[reading] * trees[reading][2] * 0.096;
		bl1 += pbtpl[reading] * trees[reading][2] * 0.04;
		bu1 += pbtpu[reading] * trees[reading][2] * 0.20;

		}
		*btp = b1;
		*btpu = bu1;
		*btpl = bl1;
}


void  galah(float *g, float *gu, float *gl)
     /*galah*/
{
	int reading; float pbtp[READINGS]; float pbtpl[READINGS]; float pbtpu[READINGS];
	float n[READINGS]; float s[READINGS]; float c[READINGS];
        float s1[READINGS]; float s2[READINGS];
	float b1 = 0; float bu1 = 0; float bl1 = 0;
	for (reading = 1; reading < count + 1; reading++)

		{                     

		n[reading] = (4.330 - (trees[reading][1]) * 0.0480);
		s1[reading] = pow (trees[reading][1], 2) * 0.0000342;
		s2[reading] = 0.004692 * trees[reading][1];
		s[reading] = 0.1803302 + s1[reading] - s2[reading];
		c[reading] = (sqrt (s[reading])) * 1.96;

		pbtp[reading] = (1 / (1 + exp (n[reading])));
		pbtpl[reading] = (1 / (1 + exp (n[reading] - c[reading])));
		pbtpu[reading] = (1 / (1 + exp (n[reading] + c[reading])));

		if (trees[reading][1] < 47.20) pbtp[reading] = 0;
		if (trees[reading][1] < 47.20) pbtpu[reading] = 0;
		if (trees[reading][1] < 47.20) pbtpl[reading] = 0;

		b1 += pbtp[reading] * trees[reading][2] * 0.310;
		bl1 += pbtpl[reading] * trees[reading][2] * 0.16;
		bu1 += pbtpu[reading] * trees[reading][2] * 0.43;

		}
		*g = b1;
		*gu = bu1;
		*gl = bl1;
}

void  plp(float *pl2, float *plu, float *pll)
   /*plp*/


{
	int reading; float pbtp[READINGS]; float pbtpl[READINGS]; float pbtpu[READINGS];
	float n[READINGS]; float s[READINGS]; float c[READINGS];
        float s1[READINGS]; float s2[READINGS];
	float b1 = 0; float bu1 = 0; float bl1 = 0;
	for (reading = 1; reading < count + 1; reading++)

		{

		n[reading] = (4.0063 - (trees[reading][1]) * 0.0447);
		s1[reading] = pow (trees[reading][1], 2) * 0.0000314;
		s2[reading] = 0.00422 * trees[reading][1];
		s[reading] = 0.15958 + s1[reading] - s2[reading];
		c[reading] = (sqrt (s[reading])) * 1.96;

		pbtp[reading] = (1 / (1 + exp (n[reading])));
		pbtpl[reading] = (1 / (1 + exp (n[reading] - c[reading])));
		pbtpu[reading] = (1 / (1 + exp (n[reading] + c[reading])));

		if (trees[reading][1] < 32.00) pbtp[reading] = 0;
		if (trees[reading][1] < 32.00) pbtpu[reading] = 0;
		if (trees[reading][1] < 32.00) pbtpl[reading] = 0;

		b1 += pbtp[reading] * trees[reading][2] * 0.200;
		bl1 += pbtpl[reading] * trees[reading][2] * 0.10;
		bu1 += pbtpu[reading] * trees[reading][2] * 0.34;

		}
		*pl2 = b1;
		*plu = bu1;
		*pll = bl1;
}


void  cor(float *c, float *cu, float *cl)
   /*cor*/

{
	int reading; float pbtp[READINGS]; float pbtpl[READINGS]; float pbtpu[READINGS];
	float n[READINGS]; float s[READINGS]; float cz[READINGS];
	float s1[READINGS]; float s2[READINGS];
	float b1 = 0; float bu1 = 0; float bl1 = 0;
	for (reading = 1; reading < count + 1; reading++)

		{

		n[reading] = (5.8500 - (trees[reading][1]) * 0.0469);
		s1[reading] = pow (trees[reading][1], 2) * 0.000013;
		s2[reading] = 0.00250 * trees[reading][1];
		s[reading] = 0.16660 + s1[reading] - s2[reading];
		cz[reading] = (sqrt (s[reading])) * 1.96;

		pbtp[reading] = (1 / (1 + exp (n[reading])));
		pbtpl[reading] = (1 / (1 + exp (n[reading] - cz[reading])));
		pbtpu[reading] = (1 / (1 + exp (n[reading] + cz[reading])));

		if (trees[reading][1] < 57.40) pbtp[reading] = 0;
		if (trees[reading][1] < 57.40) pbtpu[reading] = 0;
		if (trees[reading][1] < 57.40) pbtpl[reading] = 0;

		b1 += pbtp[reading] * trees[reading][2] * 0.100;
		bl1 += pbtpl[reading] * trees[reading][2] * 0.0;
		bu1 += pbtpu[reading] * trees[reading][2] * 0.45;

		}
		*c = b1;
		*cu = bu1;
		*cl = bl1;
}



void  hollows(void)
{
	float b = 0; float bu = 0; float bl = 0;
	float g = 0; float gu = 0; float gl = 0;
	float c = 0; float cu = 0; float cl = 0;
	float pl2 = 0; float plu = 0; float pll = 0;
	
   btp(&b, &bu, &bl);
   galah(&g, &gu, &gl);
   plp(&pl2, &plu, &pll);
   cor(&c, &cu, &cl);
   clrscr();                                /* clear the screen */

   printf("\n\tOutput for year: %d\n", time);

   printf("\nSpecies\t\t\thollows per");
   printf("\n\t\t\tha available\t lower 95 cl\t upper 95 cl\n");
   printf("\nBrush-tailed possum \t%4.2f\t\t%4.2f\t\t%4.2f", b, bl, bu);
   printf("\nGalah \t\t\t%4.2f\t\t%4.2f\t\t%4.2f", g, gl, gu);
   printf("\nPort Lincoln parrot \t%4.2f\t\t%4.2f\t\t%4.2f", pl2, pll, plu);
   printf("\nCorellas\t\t%4.2f\t\t%4.2f\t\t%4.2f\n\n", c, cl, cu);

   printf("\nPress any key to continue");

   getch();                               /* Wait for a key press */
}

void  table_view(void)

{
   float t[12]; float p[11]; int reading = 0;

   for (reading = 0; reading < 12; reading ++)
      t[reading] = 0;
   for (reading = 0; reading < 11; reading ++)
      p[reading] = 0;


   clrscr();                                /* clear the screen */
   class(t, p);

   printf("\n\tOutput for year: %d\n", time);
   printf("\nTrees per hectare 0-10 cm dbh: \t\t%5.2f", t[1]);
   printf("\nTrees per hectare 10-20 cm dbh: \t%5.2f", t[2]);
   printf("\nTrees per hectare 20-30 cm dbh: \t%5.2f", t[3]);
   printf("\nTrees per hectare 30-40 cm dbh: \t%5.2f", t[4]);
   printf("\nTrees per hectare 40-50 cm dbh: \t%5.2f", t[5]);
   printf("\nTrees per hectare 50-60 cm dbh: \t%5.2f", t[6]);
   printf("\nTrees per hectare 60-70 cm dbh: \t%5.2f", t[7]);
   printf("\nTrees per hectare 70-80 cm dbh: \t%5.2f", t[8]);
   printf("\nTrees per hectare 80-90 cm dbh: \t%5.2f", t[9]);
   printf("\nTrees per hectare 90-100 cm dbh: \t%5.2f", t[10]);
   printf("\nTrees per hectare >100 cm dbh: \t\t%5.2f\n", t[11]);
   printf("\nTotal trees per hectare is: \t\t%5.2f\n", max);
   printf("\nPress any key to continue");

   getch();                               /* Wait for a key press */
}

void  graph_view(void)

{
   			      /* clear the screen */
   float t[12]; float p[11]; int reading = 0;
   int gerr;
   int  graphdriver = DETECT, graphmode;
   int  maxx, maxy, left, top, right, bottom, width, deep;
   int  base;                          /* zero x-axis for graph */
   int  vscale = 2.5;      /* value to scale vertical bar size */
   int  space = 10;                     /* spacing between bars */
   int dclass = 11;
   float  value;
   char fprint[20];               /* formatted text for sprintf */
   char mprint[20];
   char tprint[20];
   clrscr();
   initgraph(&graphdriver, &graphmode, "");
   if ((gerr = graphresult()) != grOk)
   {
	printf("error : %s\n", grapherrormsg(gerr));
	exit(1);
   }
   if (graphresult() < 0)           /* make sure initialized OK */
      return;

   maxx  = getmaxx() / 1.3;         /* farthest right you can go */
   width = maxx / (dclass + 1); /* scale and allow for spacing */
   maxy  = getmaxy() - 100;              /* leave room for text */
   left  = 25;
   right = width;
   base  = maxy - 20;
   deep = (int) (width / 4);
   
   for (reading = 0; reading < 12; reading ++)
      t[reading] = 0;
   for (reading = 0; reading < 11; reading ++)
      p[reading] = 0;
   class(t, p);
   
   for (reading = 0; reading < 11; reading++)
   {
      value = p[reading] * vscale;
      if (value > 0.00)
      {
	 top = base - value;            /* toward top of screen */
	 bottom = base;
	 setfillstyle(HATCH_FILL, 0);
      }
      else
      {
         top = base;
         bottom = base - value;      /* toward bottom of screen */
	 setfillstyle(WIDE_DOT_FILL, 0);
      }
      bar3d(left, top, (left + width ), bottom, deep, 1);
      left  += (width + space);       /* space over for next bar */
      right += (width + space);        /* right edge of next bar */
   }

   outtextxy(0, base, "0 -");
   sprintf(mprint, "%f -", max);
   outtextxy(0, base - 220, mprint);
   outtextxy(0, base - 230, "Trees per ha");
   outtextxy(10, maxy + 20, "Plot of Tree diameter distribution");
   for (reading = 0; reading < dclass; reading++)
   {
      sprintf(fprint, "dc%d", reading * 10);
      outtextxy((reading *(width + space)) + 25, maxy + 40, fprint);
   }
   sprintf(tprint, "%d ", time);
   outtextxy(55, base - 290, tprint);
   outtextxy(50, base - 300, "Output for year:");
   outtextxy(50, maxy+80, "Press any key to continue");

   getch();                               /* Wait for a key press */

   closegraph();
}


void  assumption(void)

{
      clrscr();                                /* clear the screen */

   printf("This model is based on a sample of 242 jarrah and 66 marri on 16 "
	"transects\nat 6 sites near: Jarrahdale, Dwellingup, Harvey, Manjimup, "
	"Busselton, and \nNannup. Logisitic regression was used to predict the "
	"probability of a hollow \nof a size appropriate for each species occurring "
	"in a tree based on tree dbh,\nsilvicultural class, and bole length, as "
	 "described by Spencer (1992), \nApplication of Modern Inventory Techniques "
	 "in the forests of \nwestern Australia. The model is applicable to "
	 "mixed jarrah-marri forests, \nwhere jarrah dominates. The hollow "
	 "sizes used as the basis for the model \nare as follows:\n\n\n");
	printf("Press a key to continue...");

    getch();                               /* Wait for a key press */
    clrscr();

  printf("\n\nSpecies\t\tEntrance\tHeight\tInterior\tDepth\t   Source\n");
  printf("\t\tdiameter\tabove\tdiameter\tof hollow\n");
  printf("\t\t\t\tground\n");
  printf("\t\t (cm)\t\t (m)\t  (cm)\t\t  (cm)\n");
  printf("Brush-tailed\n");
  printf("  possum\t6-49\t\t>0.5\t8-48\t\t0-390\t   1\n");
  printf("Red-tailed black\n");
  printf("  cockatoo\t14.7-53.5\t>4.4\t19-54\t\t45-725\t   2\n");
  printf("Corellas\t10.5-40\t\t>14.3\t14-40\t\t45-453\t   2\n");
  printf("Galah\t\t6.5-30\t\t>4.7\t10-31\t\t32-377\t   2\n");
  printf("Port Lincoln");
  printf ("\n  parrot\t6.5-25\t\t>5.3\t9-17.5\t\t45-213\t   2\n");
  printf("Striated");
  printf("\n  pardalote\t2.4-6.0\t\t>10\t2.4-6.0\t\t9-35\t   3\n\n");
  printf("1. Inions et al. 1989.\n");
  printf("2. Saunders et al. 1982.\n");
  printf("3. Haseler and Taylor 1993.\n\n\n");
  
  printf("\nPress any key to continue");

   getch();                               /* Wait for a key press */
}

void  output(void)

{
   FILE *outfile;
   char file_name[512];
   int reading = 0;
	float b = 0; float bu = 0; float bl = 0;
	float g = 0;  float gu = 0; float gl = 0;
	float c = 0;  float cu = 0; float cl = 0;
	float pl2 = 0;  float plu = 0; float pll = 0;
	float t[12]; float pc[11];


   for (reading = 0; reading < 12; reading ++)
      t[reading] = 0;
   for (reading = 0; reading < 11; reading ++)
      pc[reading] = 0;
   clrscr();          
   class(t, pc);
   btp(&b, &bu, &bl);
   galah(&g, &gu, &gl);
   plp(&pl2, &plu, &pll);
   cor(&c, &cu, &cl);
   {
	char inbuf[512];
	char title1[512];
	char title2[512];
	char title3[512];
	char title4[512];
	char title5[512];
	   clrscr();
	printf("\nEnter the title for your output file \n");
            	gets(inbuf);
		sscanf(inbuf, " %s %s %s %s %s ", &title1, &title2, &title3, &title4, &title5);

   printf("\nSave to what filename? ");

   while (kbhit());  /* "eat" any char already in keyboard buffer */
   gets(file_name);

   if ((outfile = fopen(file_name,"a")) == NULL)
   {
      perror("\n\aOpen failed! ");
      return;
   }
   fprintf(outfile, "\n %s %s %s %s %s\n", title1, title2, title3, title4, title5);
   fprintf(outfile, "\n\nOutput for year: %d\n", time);
   fprintf(outfile, "\nTrees per hectare 0-10 cm dbh: \t\t%5.2f", t[1]);
   fprintf(outfile, "\nTrees per hectare 10-20 cm dbh: \t%5.2f", t[2]);
   fprintf(outfile, "\nTrees per hectare 20-30 cm dbh: \t%5.2f", t[3]);
   fprintf(outfile, "\nTrees per hectare 30-40 cm dbh: \t%5.2f", t[4]);
   fprintf(outfile, "\nTrees per hectare 40-50 cm dbh: \t%5.2f", t[5]);
   fprintf(outfile, "\nTrees per hectare 50-60 cm dbh: \t%5.2f", t[6]);
   fprintf(outfile, "\nTrees per hectare 60-70 cm dbh: \t%5.2f", t[7]);
   fprintf(outfile, "\nTrees per hectare 70-80 cm dbh: \t%5.2f", t[8]);
   fprintf(outfile, "\nTrees per hectare 80-90 cm dbh: \t%5.2f", t[9]);
   fprintf(outfile, "\nTrees per hectare 90-100 cm dbh: \t%5.2f", t[10]);
   fprintf(outfile, "\nTrees per hectare >100 cm dbh: \t\t%5.2f\n", t[11]);

   fprintf(outfile, "\nSpecies\t\t\thollows per");
   fprintf(outfile, "\n\t\t\tha available\tlower 95 cl\tupper 95 cl\n");
   fprintf(outfile, "\nBrush-tailed possum \t%4.2f\t\t%4.2f\t\t%4.2f", b, bl, bu);
   fprintf(outfile, "\nGalah \t\t\t%4.2f\t\t%4.2f\t\t%4.2f", g, gl, gu);
   fprintf(outfile, "\nPort Lincoln parrot \t%4.2f\t\t%4.2f\t\t%4.2f", pl2, pll, plu);
   fprintf(outfile, "\nCorellas\t\t%4.2f\t\t%4.2f\t\t%4.2f\n\n", c, cl, cu);

   	fclose(outfile);
  }
}

void  restart(void)

{  	int reading = 0;
	for (reading = 1; reading < READINGS; reading++)
     {
	trees[reading][1] = 0;
        trees[reading][2] = 0;
	trees[reading][3] = 0;
	}


	time = 0;
}

void space(void)
{
	int gerr;
	int  graphdriver = DETECT, graphmode;
	char inbuf[512];
	float stand = 0; float srad = 0;
	float btprad = 0;
	float galrad = 0;
	float parrad = 0;
        int max_x, max_y;           /* Maximum x- and y-coordinates */
	int y_org;                  /* Y-coordinate for all drawings */
	int au1;                    /* One unit in pixels
				*/
	float x_pos;
	float radius;
	int color;
	int fill_style;

	{
   char inbuf[512];
   printf("\nEnter the size of the area that you are assessing in ha:\n");
   gets(inbuf);
   sscanf(inbuf, "%f", &stand);
   srad = (sqrt ((stand * 10000) / 3.1416));
   btprad = 56 / srad;
   galrad = 1261 / srad;
   parrad = 36 / srad;

	}

	{
   printf("\nThe area is large enough to provide the following number of\n");
   printf("exclusive home ranges or territories for each species:\n");
   printf("Species\t\t\tHome ranges\n\n");
   printf("Brush-tailed possum\t%f\n", stand);
   printf("Galah\t\t\t%f\n", stand / 500);
   printf("Striated pardalote\t%f\n\n", stand / 0.4);

   printf("press any key to view graphics display...");

     getch();                               /* Wait for a key press */
	}

  
   initgraph(&graphdriver, &graphmode, "");
   if ((gerr = graphresult()) != grOk)
   {
	printf("error : %s\n", grapherrormsg(gerr));
	exit(1);
   }
   if (graphresult() < 0)           /* make sure initialized OK */
      return;
   {
   /* Set global variables for drawing */
   max_x = getmaxx();           /* Returns maximum x-coordinate */
   max_y = getmaxy();           /* Returns maximum y-coordinate */
   y_org = max_y / 2;           /* Set Y coord for all objects */
   srad = max_x  / 200;         /* One earth radius in pixels */
   au1 = srad * 20;             /* Scale for inner planets */

   }


   {
   /* Stand */
   color = EGA_WHITE;
   x_pos = 4.4 * au1;
   radius = srad*10;
   fill_style =  SOLID_FILL;
   setcolor (color);                /* This becomes drawing color */
   circle(x_pos, y_org, radius);    /* Draw the circle */
   setfillstyle(fill_style, color); /* Set pattern to fill interior */
   floodfill(x_pos, y_org, color);  /* Fill the circle */
   }
   {
   /* Galah */
  
   color = EGA_WHITE;
   x_pos = 1.4 * au1;
   radius = galrad*srad*10;
   fill_style =  EMPTY_FILL;
   setcolor (color);                /* This becomes drawing color */
   circle(x_pos, y_org, radius);    /* Draw the circle */
   setfillstyle(fill_style, color); /* Set pattern to fill interior */
   floodfill(x_pos, y_org, color);  /* Fill the circle */
   
   }
   {
   /* Possum */
   color = EGA_WHITE;
   x_pos = 9.0 * au1;
   radius = btprad*srad*10;
   fill_style =  CLOSE_DOT_FILL;
   setcolor (color);                /* This becomes drawing color */
   circle(x_pos, y_org, radius);    /* Draw the circle */
   setfillstyle(fill_style, color); /* Set pattern to fill interior */
   floodfill(x_pos, y_org, color);  /* Fill the circle */
   }
   {
   /* Pardalote */
   color = EGA_WHITE;
   x_pos = 6.4 * au1;
   radius = parrad*srad*10;
   fill_style =  SOLID_FILL;
   setcolor (color);                /* This becomes drawing color */
   circle(x_pos, y_org, radius);    /* Draw the circle */
   setfillstyle(fill_style, color); /* Set pattern to fill interior */
   floodfill(x_pos, y_org, color);  /* Fill the circle */
   }

  {
   outtextxy(4.4 * au1, y_org - 80, "Your area of");
   outtextxy(4.4 * au1, y_org - 70, "assessment");
   outtextxy(1.4 * au1, y_org - 80, "Galah");
   outtextxy(1.4 * au1, y_org - 70, "territory");
   outtextxy(9.0 * au1, y_org - 80, "Brush-tailed");
   outtextxy(9.0 * au1, y_org - 70, "possum");
   outtextxy(9.0 * au1, y_org - 60, "home range");
   outtextxy(6.4 * au1, y_org - 80, "Striated");
   outtextxy(6.4 * au1, y_org - 70, "pardalote");
   outtextxy(6.4 * au1, y_org - 60, "territory");
   outtextxy(0.4, max_y - 20, "Press any key to exit");
   getch();
   closegraph();
  }

}

void  growhi(void)

{
	int year = 0;
	int reading = 0;
	float grow = 0; float mort = 0;
        clrscr();
	{
	char inbuf[512];
	printf("\nEnter the number of years that you want to grow the stand: \n");
	gets(inbuf);
	sscanf(inbuf, "%d", &year);
	}

	time += year;
	
	for (reading = 1; reading < count + 1; reading++)
	{
	if (trees[reading][3] > 0)
	{
	if (trees[reading][1] < 45)
	  {
	  grow = 0.1 * year;
	  trees[reading][1] += grow;
	  }
	else if (trees[reading][1] < 100)
	  {
	  grow = 0.1 * year;
	  trees[reading][1] += grow;
	  mort = trees[reading][2] * ((trees[reading][1] * 0.0049) - 0.19) * 0.01;
	  trees[reading][2] = trees[reading][2] - mort;
	  }

	else
	  {
	  grow = 0.07 * year;
	  trees[reading][1] += grow;
	  mort = 0.003 * year;
	  trees[reading][2] = trees[reading][2] - mort;
	  }

	}

     }
	printf("Growth completed.\n");
	printf("Press any key to return to the menu...");
	getch();                               /* Wait for a key press */

       clrscr();


}

void  growlo(void)

{
	int year = 0;
	int reading = 0;
	float grow = 0; float mort = 0;
        clrscr();
	{
	char inbuf[512];
	printf("\nEnter the number of years that you want to grow the stand: \n");
	gets(inbuf);
	sscanf(inbuf, "%d", &year);
	}

	time += year;

	for (reading = 1; reading < count + 1; reading++)
	{
	if (trees[reading][3] > 0)
	{
	if (trees[reading][1] < 45)
	  {
	  grow = 0.03 * year;
	  trees[reading][1] += grow;
	  }
	else if (trees[reading][1] < 100)
	  {
	  grow = 0.03 * year;
	  trees[reading][1] += grow;
	  mort = 0.006 * year;
	  trees[reading][2] = trees[reading][2] - mort;
	  }

	else
	  {
	  grow = 0.05 * year;
	  trees[reading][1] += grow;
	  mort = 0.006 * year;
	  trees[reading][2] = trees[reading][2] - mort;
	  }
	}

        }

	printf("Growth completed.\n");
	printf("Press any key to return to the menu...");
	getch();                               /* Wait for a key press */

       clrscr();


}


void  harvest(void)

{
	float pct20 = 0, pct50 = 0, pct100 = 0;

	{
	char inbuf[512];
	printf("\nEnter the percent of trees < 20 cm that you would like to harvest: \n\n");
	gets(inbuf);
	sscanf(inbuf, "%f", &pct20);
	
	}
	{
	char inbuf[512];
	printf("\nEnter the percent of trees 20 - 50 cm that you would like to harvest: \n\n");
	gets(inbuf);
	sscanf(inbuf, "%f", &pct50);
	

	}
	{
	char inbuf[512];
	printf("\nEnter the percent of trees > 50 cm that you would like to harvest: \n\n");
	gets(inbuf);
	sscanf(inbuf, "%f", &pct100);
	

	}

	 printf("\n\nPress any key to return to the menu...");
	getch();                               /* Wait for a key press */

       clrscr();

}



void  ingrowth(void)

{
clrscr();
printf("\nSorry. This function has not yet been completed.\n\n");

	printf("Press any key to return to the menu...");
	getch();                               /* Wait for a key press */

       clrscr();
}